==> gameap-3.1-shared.zip: upload/resources/lang/en/home.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Home page Language Lines
    |--------------------------------------------------------------------------
    |
    |
    */

    'main'              => 'Main',
    'servers_list'      => 'Servers list',

    'your_version'      => 'Your version',
    'latest_stable'     => 'Latest stable',
    'latest_beta'       => 'Latest beta',
    'latest_unstable'   => 'Latest unstable',
    
    'old_version'       => 'Your GameAP version is old',
    'actual_version'    => 'Your GameAP version is actual',
    'dev_version'       => 'Your GameAP version is unknown or dev',

    'information'       => 'Information',
    'problems'          => 'Problems',
    'get_help'          => 'Get Help',
    'documentation'     => 'Documentation',
    'report_bug'        => 'Report a bug',
    'update'            => 'Check for updates',

    'd_report_bug'      => 'Please check the PHP version and the availability of the necessary PHP extensions.
                        PHP versions should be no lower than the minimum recommended.
                        Some functions of the panel will not work correctly without the necessary extensions',
    'send_report'       => 'Send report',
    'system_check'      => 'System check',

    'send_bug_success_msg' => 'Error message sent successfully',

    'problems_list'     => [
        'required_extenstions_are_missed' => 'Required PHP extenstions are missed: :extensions',
        'nodes_is_not_available'          => 'Some dedicated servers are not available. Failed to connect to the following dedicated servers: :nodes',
        'not_writable_directories'        => 'The following directories are not writable: :paths',
    ]
];

==> gameap-3.2-shared.zip: upload/resources/lang/en/home.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Home page Language Lines
    |--------------------------------------------------------------------------
    |
    |
    */

    'main'              => 'Main',
    'servers_list'      => 'Servers list',

    'your_version'      => 'Your version',
    'latest_stable'     => 'Latest stable',
    'latest_beta'       => 'Latest beta',
    'latest_unstable'   => 'Latest unstable',
    
    'old_version'       => 'Your GameAP version is old',
    'actual_version'    => 'Your GameAP version is actual',
    'dev_version'       => 'Your GameAP version is unknown or dev',

    'information'       => 'Information',
    'problems'          => 'Problems',
    'get_help'          => 'Get Help',
    'documentation'     => 'Documentation',
    'api_documentation' => 'API Documentation',
    'report_bug'        => 'Report a bug',
    'update'            => 'Check for updates',
    'channels'          => 'Channels',
    'support_gameap'    => 'Support GameAP',
    'need_help'         => 'Need help?',

    'd_report_bug'      => 'Please check the PHP version and the availability of the necessary PHP extensions.
                        PHP versions should be no lower than the minimum recommended.
                        Some functions of the panel will not work correctly without the necessary extensions',
    'send_report'       => 'Send report',
    'system_check'      => 'System check',

    'send_bug_success_msg' => 'Error message sent successfully',

    'problems_list'     => [
        'required_extenstions_are_missed' => 'Required PHP extenstions are missed: :extensions',
        'nodes_is_not_available'          => 'Some dedicated servers are not available. Failed to connect to the following dedicated servers: :nodes',
        'not_writable_directories'        => 'The following directories are not writable: :paths',
    ]
];
